
%This is an example code, demonstrating how to use the main functions supplied. 
% 
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% M. Mordechay and Y. Y. Schechner, "Matrix optimization for poisson compressed
% sensing," in Proceedings of IEEE GlobalSIP, December 2014, pp.684-688.
%
% (c) Copyright Moran Mordechay 2014. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 


m= 1024;
p= 256;
pr = 0.8;

% Creating a random nonnegative matrix with p rows and m columns,
% where pr is the probability for a matrix element to be null.
% Such a random nonnegative matrix was described in the following paper:
% M. Raginsky, Z. T. Harmany, R. F. Marcia, and R. M. Willett, "Compressed
% sensing performance bounds under poisson noise," IEEE Transactions on
% Signal Processing, vol. 58, no. 8, pp. 3990 - 4002, 2010.

z = zeros(p,m);
temp = rand(p,m);
inds = find(temp<pr);
z(inds) = -1*sqrt((1-pr)/pr);
inds2 = find(temp>=pr);
z(inds2) = sqrt(pr/(1-pr));
phi = z/sqrt(p);
phi = phi * sqrt(pr*(1-pr)/p) + ones(p,m)*(1-pr)/p;

% Normalizing the columns of phi to satisfy energy conservation.
[ phi ] = normalize_col_sum( phi );

% Calculating the mutual coherence and average mutual coherence of phi.
[ coh_init, coh_avg_init ] = calc_coherence( phi, eye(m) );

% Optimizing phi
[ phi_opt, coh, coh_avg, coh_vec, coh_avg_vec ] = opt_measurements_mat( phi, eye(m), 0.35, 0.1, 0.5, 0.9, 100, 50 );

